==> s2m-2.5.tar.gz: s2m-2.5/README.md <==
![logo](https://raw.github.com/MrYsLab/s2m/master/images/logo.png)
======
# Bringing _**You**_, _**Scratch**_, and _**micro:bit**_ together!

__*s2m*__ is a Python program that acts as a bridge between the Scratch 2 off-line editor
 and the micro:bit computer. It allows you to easily create Scratch programs that interact with the micro:bit.

![logo](https://raw.github.com/MrYsLab/s2m/master/images/launch.png)

__MAJOR FEATURES__

* s2m is compatible with both Python 2 and Python 3.

* It runs on Windows, Mac, Raspberry Pi and Linux.

* It is easy to install.

* It is easy to use.

* It is a whole lot of fun!

* English, [Brazilian-Portuguese](https://mryslab.github.io/s2m/blocks/#the-brazilian-portuguese-blocks), 
[Japanese](https://mryslab.github.io/s2m/blocks/#the-japanese-blocks),
[Korean](https://mryslab.github.io/s2m/blocks/#the-korean-blocks), and 
[Traditional (tw) Chinese](https://mryslab.github.io/s2m/blocks/#the-traditional-chinese-tw-blocks) 
blocks are available for use.

* If you would like to translate the blocks to your native language, check out
the [translation instructions in the User's Guide](https://mryslab.github.io/s2m/translation/)
    * Submit your translation, and it will become part of the s2m distribution package, with your name
    added to the list of translation contributors in the User's Guide.


__For installation and usage instructions, please read the [users guide](https://mryslab.github.io/s2m/)__.


This project was developed with [Pycharm](https://www.jetbrains.com/pycharm/)![pyc](https://raw.github.com/MrYsLab/s2m/master/images/icon_PyCharm.png)

==> s2m-2.10.tar.gz: s2m-2.10/README.md <==
![logo](https://raw.github.com/MrYsLab/s2m/master/images/logo.png)
======
# Bringing _**You**_, _**Scratch**_, and _**micro:bit**_ together!

__*s2m*__ is a Python program that acts as a bridge between the Scratch 2 off-line editor
 and the micro:bit computer. It allows you to easily create Scratch programs that interact with the micro:bit.

![logo](https://raw.github.com/MrYsLab/s2m/master/images/launch.png)

__MAJOR FEATURES__

* s2m is compatible with both Python 2 and Python 3.

* It runs on Windows, Mac, Raspberry Pi and Linux.

* It is easy to install.

* It is easy to use.

* It is a whole lot of fun!

* English, [Brazilian-Portuguese](https://mryslab.github.io/s2m/blocks/#the-brazilian-portuguese-blocks), 
[Japanese](https://mryslab.github.io/s2m/blocks/#the-japanese-blocks),
[Korean](https://mryslab.github.io/s2m/blocks/#the-korean-blocks),
[Spanish](https://mryslab.github.io/s2m/blocks/#the-spanish-blocks) and
[Traditional (tw) Chinese](https://mryslab.github.io/s2m/blocks/#the-traditional-chinese-tw-blocks) 
blocks are available for use.

* If you would like to translate the blocks to your native language, check out
the [translation instructions in the User's Guide](https://mryslab.github.io/s2m/translation/)
    * Submit your translation, and it will become part of the s2m distribution package, with your name
    added to the list of translation contributors in the User's Guide.


__For installation and usage instructions, please read the [users guide](https://mryslab.github.io/s2m/)__.


This project was developed with [Pycharm](https://www.jetbrains.com/pycharm/)![pyc](https://raw.github.com/MrYsLab/s2m/master/images/icon_PyCharm.png)
